types

package
v0.3.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 18, 2025 License: MIT Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type ActionType

type ActionType interface {
	ValueType
	GetValue() registries.ActionRegistry
}

func NewActionValue

func NewActionValue(value registries.ActionRegistry) ActionType

NewActionValue create a new registries.Text type value. See RFC-5545 ref for more info

type BinaryType added in v0.3.0

type BinaryType interface {
	ValueType
	GetValue() string
}

func NewBinaryValue

func NewBinaryValue(value string) BinaryType

NewBinaryValue create a new registries.Binary type value. See RFC-5545 ref for more info

type BooleanType added in v0.3.0

type BooleanType interface {
	ValueType
	GetValue() bool
}

func NewBooleanValue

func NewBooleanValue(value bool) BooleanType

NewBooleanValue create a new registries.Boolean type value. See RFC-5545 ref for more info

type CalendarUserAddressType added in v0.3.0

type CalendarUserAddressType interface {
	ValueType
	GetValue() *url.URL
}

func NewCalendarUserAddressValue

func NewCalendarUserAddressValue(value *url.URL) CalendarUserAddressType

NewCalendarUserAddressValue create a new registries.CalAddress type value. See RFC-5545 ref for more info

type ClassificationType

type ClassificationType interface {
	ValueType
	GetValue() registries.ClassificationRegistry
}

func NewClassificationValue

func NewClassificationValue(value registries.ClassificationRegistry) ClassificationType

NewClassificationValue create a new registries.Text type value. See RFC-5545 ref for more info

type ComponentDelimiterType added in v0.3.0

type ComponentDelimiterType interface {
	ValueType
	GetValue() registries.ComponentRegistry
}

func NewComponentDelimiterValue added in v0.3.0

func NewComponentDelimiterValue(value registries.ComponentRegistry) ComponentDelimiterType

type DateTimeFormat added in v0.3.0

type DateTimeFormat string
const (
	WithLocalTime DateTimeFormat = "WithLocalTime"
	WithUtcTime   DateTimeFormat = "WithUtcTime"
)

type DateTimeType added in v0.3.0

type DateTimeType interface {
	ValueType
	GetValue() time.Time
	GetFormat() DateTimeFormat
}

func NewDateTimeValue

func NewDateTimeValue(value time.Time) DateTimeType

NewDurationValue create a new registries.Duration type value. See RFC-5545 ref for more info

func NewDateTimeValueFromString

func NewDateTimeValueFromString(value string) (DateTimeType, error)

NewDurationValue create a new registries.Duration type value from a string one (ex: 19980119T020000 or 19980119T070000Z). See RFC-5545 ref for more info

func NewDateTimeValueFromStrings added in v0.3.0

func NewDateTimeValueFromStrings(values []string) ([]DateTimeType, error)

NewDurationValue create a new registries.Duration type value from multiple strings (ex: 19980119T020000,20000119T020000). See RFC-5545 ref for more info

func NewDateTimeValues

func NewDateTimeValues(values []time.Time) []DateTimeType

NewDurationValue create a new registries.Duration type value array. See RFC-5545 ref for more info

type DateType added in v0.3.0

type DateType interface {
	ValueType
	GetValue() time.Time
}

func NewDateValue

func NewDateValue(value time.Time) DateType

NewDateValue create a new registries.Date type value. See RFC-5545 ref for more info

func NewDateValueFromString

func NewDateValueFromString(value string) (DateType, error)

NewDateValueFromString create a new registries.Date type value from string. See RFC-5545 ref for more info

func NewDateValues

func NewDateValues(values []time.Time) []DateType

NewDateValues create new registries.Date type values. See RFC-5545 ref for more info

func NewDateValuesFromString

func NewDateValuesFromString(values []string) ([]DateType, error)

NewDateValuesFromString create new registries.Date type values from string. See RFC-5545 ref for more info

type DurationType added in v0.3.0

type DurationType interface {
	ValueType
	GetValue() time.Duration
}

func NewDurationValue

func NewDurationValue(value time.Duration) DurationType

NewDurationValue create a new registries.Duration type value. See RFC-5545 ref for more info

func NewDurationValueFromString added in v0.3.0

func NewDurationValueFromString(value string) (DurationType, error)

NewDurationValue create a new registries.Duration type value from a string. See RFC-5545 ref for more info

type FloatType added in v0.3.0

type FloatType interface {
	ValueType
	GetValue() float64
}

func NewFloatValue

func NewFloatValue(value float64) FloatType

NewFloatValue create a new registries.Float type value. See RFC-5545 ref for more info

func NewFloatValueFromString added in v0.3.0

func NewFloatValueFromString(value string) FloatType

NewFloatValueFromString create a new registries.Float type value from a string. See RFC-5545 ref for more info

type IntegerType added in v0.3.0

type IntegerType interface {
	ValueType
	GetValue() int32
}

func NewIntegerValue

func NewIntegerValue(value int32) IntegerType

NewIntegerValue create a new registries.Integer type value. See RFC-5545 ref for more info

func NewIntegerValues

func NewIntegerValues(values []int32) []IntegerType

NewIntegerValues create a new registries.Integer type values. See RFC-5545 ref for more info

type PeriodOfTimeFormat added in v0.3.0

type PeriodOfTimeFormat string
const (
	ImplicitPeriodOfTime PeriodOfTimeFormat = "ImplicitPeriodOfTime"
	ExplicitPeriodOfTime PeriodOfTimeFormat = "ExplicitPeriodOfTime"
)

type PeriodOfTimeType added in v0.3.0

type PeriodOfTimeType interface {
	ValueType
	GetValue() (from, to time.Time)
	GetFormat() PeriodOfTimeFormat
}

func NewExplicitPeriodOfTimeValue added in v0.3.1

func NewExplicitPeriodOfTimeValue(
	fromValue time.Time,
	toValue time.Time,
) PeriodOfTimeType

NewExplicitPeriodOfTimeValue create a new registries.PeriodOfTime type value used for registries.FreeBusyTimeProp. See RFC-5545 ref for more info

func NewImplicitPeriodOfTimeValue added in v0.3.1

func NewImplicitPeriodOfTimeValue(
	fromValue time.Time,
	toValue time.Duration,
) PeriodOfTimeType

NewImplicitPeriodOfTimeValue create a new registries.PeriodOfTime type value. See RFC-5545 ref for more info

func NewPeriodOfTimeValueFromString added in v0.3.0

func NewPeriodOfTimeValueFromString(value string) (PeriodOfTimeType, error)

NewPeriodOfTimeValue create a new registries.PeriodOfTime type value. See RFC-5545 ref for more info

type StatusType

type StatusType interface {
	ValueType
	GetValue() registries.ParticipantStatusRegistry
}

type TextType added in v0.3.0

type TextType interface {
	ValueType
}

func NewTextValue

func NewTextValue(value string) TextType

NewTextValue create a new registries.Text type value. See RFC-5545 ref for more info

func NewTextValues

func NewTextValues(values []string) []TextType

NewTextValues create a new registries.Text type values. See RFC-5545 ref for more info

type TimeFormat added in v0.3.0

type TimeFormat string
const (
	TimeWithLocalTime TimeFormat = "TimeWithLocalTime"
	TimeWithUtcTime   TimeFormat = "TimeWithUtcTime"
)

type TimeTransparencyType

type TimeTransparencyType interface {
	ValueType
	GetValue() registries.TimeTransparencyRegistry
}

func NewTimeTransparencyValue

func NewTimeTransparencyValue(value registries.TimeTransparencyRegistry) TimeTransparencyType

NewTimeTransparencyValue create a new registries.TimeTransparencyRegistry type value. See RFC-5545 ref for more info

func NewTimeTransparencyValueFromString added in v0.3.0

func NewTimeTransparencyValueFromString(value string) TimeTransparencyType

NewTimeTransparencyValueFromString create a new registries.TimeTransparencyRegistry type value from a string. See RFC-5545 ref for more info

type TimeType added in v0.3.0

type TimeType interface {
	ValueType
	GetValue() time.Time
	GetFormat() TimeFormat
}

func NewTimeValue

func NewTimeValue(value time.Time) TimeType

NewTimeValue create a new registries.Time type value. See RFC-5545 ref for more info

func NewTimeValueFromString added in v0.3.0

func NewTimeValueFromString(value string) TimeType

NewTimeValueFromString create a new registries.Time type value from string. See RFC-5545 ref for more info

func NewTimeValues added in v0.3.0

func NewTimeValues(values []time.Time) []TimeType

NewTimeValues create a new registries.Time type value array. See RFC-5545 ref for more info

func NewTimeValuesFromString added in v0.3.0

func NewTimeValuesFromString(values []string) []TimeType

NewTimeValuesFromString create new registries.Time type values from string. See RFC-5545 ref for more info

type UriType added in v0.3.0

type UriType interface {
	ValueType
	GetValue() *url.URL
}

func NewUriValue

func NewUriValue(value *url.URL) UriType

NewUriValue create a new registries.Uri type value. See RFC-5545 ref for more info

func NewUriValueFromString added in v0.3.0

func NewUriValueFromString(value string) UriType

NewUriValue create a new registries.Uri type value. See RFC-5545 ref for more info

type UtcOffsetType added in v0.3.0

type UtcOffsetType interface {
	ValueType
	GetValue() int
}

func NewUtcOffsetValue

func NewUtcOffsetValue(value int) UtcOffsetType

NewTextValue create a new registries.UTCOffset type value. See RFC-5545 ref for more info

func NewUtcOffsetValueFromString added in v0.3.0

func NewUtcOffsetValueFromString(value string) UtcOffsetType

NewTextValue create a new registries.UTCOffset type value from string. See RFC-5545 ref for more info

type ValueType added in v0.3.0

type ValueType interface {
	// GetTypeName return the type name
	GetTypeName() string
	// GetStringValue return the string representation of the typed value
	GetStringValue() string
}

ValueType is the common interface of all typed value. See RFC-5545 for more info

Directories

Path Synopsis

Jump to