Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Calendar ¶
type Calendar interface {
// SerializeToICSFormat format the CalendarComponent to his RFC-5545 representation.
// It can be print inside a file or the stdout via the "output" param
SerializeToICSFormat(output io.Writer)
// MandatoryProperties return the list of the mandatory properties of the Calendar
MandatoryProperties() []registries.PropertyRegistry
// GetProperty get a property by his registries.PropertyRegistry
GetProperty(name registries.PropertyRegistry) properties.Property
// AddProperty add a new property to a Calendar
AddProperty(property properties.Property)
}
Calendar is the interface definition of a iCalendar object
func NewCalendar ¶
func NewCalendar( calendarComponent components.Component, propertyList ...properties.Property, ) (Calendar, error)
NewCalendar create a iCalendar object You can find more information in this section of the RFC-5545 : https://datatracker.ietf.org/doc/html/rfc5545#section-3.4
Click to show internal directories.
Click to hide internal directories.